@@ -19,15 +19,14 @@
 */
 
 #include "conflictresolvertest.h"
-#include "../src/conflictresolver.h"
+#include "conflictresolver.h"
 
 #include <KCalCore/Event>
 #include <KCalCore/Period>
 #include <KCalCore/Duration>
 
 #include <QWidget>
-
-#include <qtest.h>
+#include <QTest>
 
 using namespace IncidenceEditorNG;
 
@@ -38,14 +37,13 @@ void ConflictResolverTest::insertAttendees()
     }
 }
 
-void ConflictResolverTest::addAttendee(const QString &email, const KCalCore::FreeBusy::Ptr &fb,
-                                       KCalCore::Attendee::Role role)
+void ConflictResolverTest::addAttendee(const QString &email, const KCalCore::FreeBusy::Ptr &fb, KCalCore::Attendee::Role role)
 {
     QString name = QStringLiteral("attendee %1").arg(attendees.count());
     CalendarSupport::FreeBusyItem::Ptr item(new CalendarSupport::FreeBusyItem(KCalCore::Attendee::Ptr(
-                                     new KCalCore::Attendee(name, email, false,
-                                             KCalCore::Attendee::Accepted,
-                                             role)), nullptr));
+                                                                                  new KCalCore::Attendee(name, email, false,
+                                                                                                         KCalCore::Attendee::Accepted,
+                                                                                                         role)), nullptr));
     item->setFreeBusy(KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(*fb.data())));
     attendees << item;
 }
@@ -58,7 +56,7 @@ void ConflictResolverTest::initTestCase()
 
 void ConflictResolverTest::init()
 {
-    base = KDateTime::currentLocalDateTime().addDays(1);
+    base = QDateTime::currentDateTime().addDays(1);
     end = base.addSecs(10 * 60 * 60);
     resolver = new ConflictResolver(parent, parent);
 }
@@ -75,7 +73,7 @@ void ConflictResolverTest::simpleTest()
     KCalCore::Period meeting(end.addSecs(-3 * 60 * 60), KCalCore::Duration(2 * 60 * 60));
     addAttendee(QStringLiteral("albert@einstein.net"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << meeting)));
+                                                               << meeting)));
 
     insertAttendees();
 
@@ -97,7 +95,6 @@ void ConflictResolverTest::simpleTest()
     //free block doesn't start until
     //the next timeslot
     QCOMPARE(second.end(), end);
-
 }
 
 void ConflictResolverTest::stillPrettySimpleTest()
@@ -107,13 +104,13 @@ void ConflictResolverTest::stillPrettySimpleTest()
     KCalCore::Period meeting3(end.addSecs(-3 * 60 * 60), KCalCore::Duration(2 * 60 * 60));
     addAttendee(QStringLiteral("john.f@kennedy.com"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << meeting1 << meeting3)));
+                                                               << meeting1 << meeting3)));
     addAttendee(QStringLiteral("elvis@rock.com"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << meeting2 << meeting3)));
+                                                               << meeting2 << meeting3)));
     addAttendee(QStringLiteral("albert@einstein.net"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << meeting3)));
+                                                               << meeting3)));
 
     insertAttendees();
 
@@ -138,7 +135,7 @@ void ConflictResolverTest::stillPrettySimpleTest()
     QCOMPARE(second.end(), end);
 }
 
-#define _time( h, m ) KDateTime( base.date(), QTime( h, m ) )
+#define _time(h, m) QDateTime(base.date(), QTime(h, m))
 
 void ConflictResolverTest::akademy2010()
 {
@@ -176,41 +173,41 @@ void ConflictResolverTest::akademy2010()
     // adds 80 people (adds the same 8 peopl 10 times)
     addAttendee(QStringLiteral("akademyattendee1@email.com"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << opening << keynote
-                                        << oviStore << wikimedia
-                                        << direction)));
+                                                               << opening << keynote
+                                                               << oviStore << wikimedia
+                                                               << direction)));
     addAttendee(QStringLiteral("akademyattendee2@email.com"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << opening << keynote
-                                        << commAsService << highlights
-                                        << pimp)));
+                                                               << opening << keynote
+                                                               << commAsService << highlights
+                                                               << pimp)));
     addAttendee(QStringLiteral("akademyattendee3@email.com"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << opening << kdeForums
-                                        << styles << pimp  << plasma)));
+                                                               << opening << kdeForums
+                                                               << styles << pimp  << plasma)));
     addAttendee(QStringLiteral("akademyattendee4@email.com"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << opening << keynote
-                                        << oviStore << pimp << blurr)));
+                                                               << opening << keynote
+                                                               << oviStore << pimp << blurr)));
     addAttendee(QStringLiteral("akademyattendee5@email.com"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << keynote << oviStore
-                                        << highlights << avalanche)));
+                                                               << keynote << oviStore
+                                                               << highlights << avalanche)));
     addAttendee(QStringLiteral("akademyattendee6@email.com"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << opening << keynote
-                                        << commAsService
-                                        << highlights)));
+                                                               << opening << keynote
+                                                               << commAsService
+                                                               << highlights)));
     addAttendee(QStringLiteral("akademyattendee7@email.com"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << opening << kdeForums
-                                        << styles << avalanche
-                                        << pimp << plasma)));
+                                                               << opening << kdeForums
+                                                               << styles << avalanche
+                                                               << pimp << plasma)));
     addAttendee(QStringLiteral("akademyattendee8@email.com"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << opening << keynote
-                                        << oviStore << wikimedia
-                                        << blurr)));
+                                                               << opening << keynote
+                                                               << oviStore << wikimedia
+                                                               << blurr)));
 //  }
 
     insertAttendees();
@@ -244,7 +241,7 @@ void ConflictResolverTest::testPeriodIsLargerThenTimeframe()
 
     addAttendee(QStringLiteral("kdabtest1@demo.kolab.org"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << testEvent)));
+                                                               << testEvent)));
     addAttendee(QStringLiteral("kdabtest2@demo.kolab.org"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List())));
 
@@ -268,7 +265,7 @@ void ConflictResolverTest::testPeriodBeginsBeforeTimeframeBegins()
 
     addAttendee(QStringLiteral("kdabtest1@demo.kolab.org"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << testEvent)));
+                                                               << testEvent)));
     addAttendee(QStringLiteral("kdabtest2@demo.kolab.org"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List())));
 
@@ -295,7 +292,7 @@ void ConflictResolverTest::testPeriodEndsAfterTimeframeEnds()
 
     addAttendee(QStringLiteral("kdabtest1@demo.kolab.org"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << testEvent)));
+                                                               << testEvent)));
     addAttendee(QStringLiteral("kdabtest2@demo.kolab.org"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List())));
 
@@ -323,7 +320,7 @@ void ConflictResolverTest::testPeriodEndsAtSametimeAsTimeframe()
 
     addAttendee(QStringLiteral("kdabtest1@demo.kolab.org"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List()
-                                        << testEvent)));
+                                                               << testEvent)));
     addAttendee(QStringLiteral("kdabtest2@demo.kolab.org"),
                 KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KCalCore::Period::List())));
 
@@ -336,4 +333,3 @@ void ConflictResolverTest::testPeriodEndsAtSametimeAsTimeframe()
 }
 
 QTEST_MAIN(ConflictResolverTest)
-
